@@ -1,7 +1,7 @@
 /* mz_os.c -- System functions
    part of the minizip-ng project
 
-   Copyright (C) 2010-2021 Nathan Moinvaziri
+   Copyright (C) Nathan Moinvaziri
      https://github.com/zlib-ng/minizip-ng
    Copyright (C) 1998-2010 Gilles Vollant
      https://www.winimage.com/zLibDll/minizip.html
@@ -17,13 +17,14 @@
 #include "mz_strm_os.h"
 
 #include <ctype.h> /* tolower */
+#include <string.h>
 
 /***************************************************************************/
 
 int32_t mz_path_combine(char *path, const char *join, int32_t max_path) {
     int32_t path_len = 0;
 
-    if (path == NULL || join == NULL || max_path == 0)
+    if (!path || !join || !max_path)
         return MZ_PARAM_ERROR;
 
     path_len = (int32_t)strlen(path);
@@ -130,7 +131,6 @@ int32_t mz_path_resolve(const char *path, char *output, int32_t max_output) {
     const char *check = output;
     char *target = output;
 
-
     if (max_output <= 0)
         return MZ_PARAM_ERROR;
 
@@ -213,7 +213,7 @@ int32_t mz_path_resolve(const char *path, char *output, int32_t max_output) {
 int32_t mz_path_remove_filename(char *path) {
     char *path_ptr = NULL;
 
-    if (path == NULL)
+    if (!path)
         return MZ_PARAM_ERROR;
 
     path_ptr = path + strlen(path) - 1;
@@ -236,7 +236,7 @@ int32_t mz_path_remove_filename(char *path) {
 int32_t mz_path_remove_extension(char *path) {
     char *path_ptr = NULL;
 
-    if (path == NULL)
+    if (!path)
         return MZ_PARAM_ERROR;
 
     path_ptr = path + strlen(path) - 1;
@@ -261,7 +261,7 @@ int32_t mz_path_remove_extension(char *path) {
 int32_t mz_path_get_filename(const char *path, const char **filename) {
     const char *match = NULL;
 
-    if (path == NULL || filename == NULL)
+    if (!path || !filename)
         return MZ_PARAM_ERROR;
 
     *filename = NULL;
@@ -271,7 +271,7 @@ int32_t mz_path_get_filename(const char *path, const char **filename) {
             *filename = match + 1;
     }
 
-    if (*filename == NULL)
+    if (!*filename)
         return MZ_EXIST_ERROR;
 
     return MZ_OK;
@@ -279,21 +279,14 @@ int32_t mz_path_get_filename(const char *path, const char **filename) {
 
 int32_t mz_dir_make(const char *path) {
     int32_t err = MZ_OK;
-    size_t len = 0;
     char *current_dir = NULL;
     char *match = NULL;
     char hold = 0;
 
-
-    len = strlen(path);
-    if (len <= 0 || len > INT16_MAX)
-        return 0;
-
-    current_dir = (char *)MZ_ALLOC(len + 1);
-    if (current_dir == NULL)
+    current_dir = strdup(path);
+    if (!current_dir)
         return MZ_MEM_ERROR;
 
-    strcpy(current_dir, path);
     mz_path_remove_slash(current_dir);
 
     err = mz_os_make_dir(current_dir);
@@ -316,7 +309,7 @@ int32_t mz_dir_make(const char *path) {
         }
     }
 
-    MZ_FREE(current_dir);
+    free(current_dir);
     return err;
 }
 
