@@ -1,28 +1,22 @@
 /* mz_os_win32.c -- System functions for Windows
    part of the minizip-ng project
 
-   Copyright (C) 2010-2021 Nathan Moinvaziri
+   Copyright (C) Nathan Moinvaziri
      https://github.com/zlib-ng/minizip-ng
 
    This program is distributed under the terms of the same license as zlib.
    See the accompanying LICENSE file for the full text of the license.
 */
 
-
 #include "mz.h"
 #include "mz_os.h"
 #include "mz_strm_os.h"
 
 #include <windows.h>
+#include <winioctl.h>
 
 /***************************************************************************/
 
-#if defined(WINAPI_FAMILY_PARTITION) && (!(defined(MZ_WINRT_API)))
-#  if !WINAPI_FAMILY_PARTITION(WINAPI_PARTITION_DESKTOP)
-#    define MZ_WINRT_API 1
-#  endif
-#endif
-
 #ifndef SYMBOLIC_LINK_FLAG_DIRECTORY
 #  define SYMBOLIC_LINK_FLAG_DIRECTORY 0x1
 #endif
@@ -45,19 +39,17 @@ wchar_t *mz_os_unicode_string_create(const char *string, int32_t encoding) {
     string_wide_size = MultiByteToWideChar(encoding, 0, string, -1, NULL, 0);
     if (string_wide_size == 0)
         return NULL;
-    string_wide = (wchar_t *)MZ_ALLOC((string_wide_size + 1) * sizeof(wchar_t));
-    if (string_wide == NULL)
+    string_wide = (wchar_t *)calloc(string_wide_size + 1, sizeof(wchar_t));
+    if (!string_wide)
         return NULL;
 
-    memset(string_wide, 0, sizeof(wchar_t) * (string_wide_size + 1));
     MultiByteToWideChar(encoding, 0, string, -1, string_wide, string_wide_size);
-
     return string_wide;
 }
 
 void mz_os_unicode_string_delete(wchar_t **string) {
-    if (string != NULL) {
-        MZ_FREE(*string);
+    if (string) {
+        free(*string);
         *string = NULL;
     }
 }
@@ -70,12 +62,10 @@ uint8_t *mz_os_utf8_string_create(const char *string, int32_t encoding) {
     string_wide = mz_os_unicode_string_create(string, encoding);
     if (string_wide) {
         string_utf8_size = WideCharToMultiByte(CP_UTF8, 0, string_wide, -1, NULL, 0, NULL, NULL);
-        string_utf8 = (uint8_t *)MZ_ALLOC((string_utf8_size + 1) * sizeof(wchar_t));
+        string_utf8 = (uint8_t *)calloc(string_utf8_size + 1, sizeof(wchar_t));
 
-        if (string_utf8) {
-            memset(string_utf8, 0, string_utf8_size + 1);
+        if (string_utf8)
             WideCharToMultiByte(CP_UTF8, 0, string_wide, -1, (char *)string_utf8, string_utf8_size, NULL, NULL);
-        }
 
         mz_os_unicode_string_delete(&string_wide);
     }
@@ -90,19 +80,17 @@ uint8_t *mz_os_utf8_string_create_from_unicode(const wchar_t *string, int32_t en
     MZ_UNUSED(encoding);
 
     string_utf8_size = WideCharToMultiByte(CP_UTF8, 0, string, -1, NULL, 0, NULL, NULL);
-    string_utf8 = (uint8_t *)MZ_ALLOC((string_utf8_size + 1) * sizeof(wchar_t));
+    string_utf8 = (uint8_t *)calloc(string_utf8_size + 1, sizeof(wchar_t));
 
-    if (string_utf8) {
-        memset(string_utf8, 0, string_utf8_size + 1);
+    if (string_utf8)
         WideCharToMultiByte(CP_UTF8, 0, string, -1, (char *)string_utf8, string_utf8_size, NULL, NULL);
-    }
 
     return string_utf8;
 }
 
 void mz_os_utf8_string_delete(uint8_t **string) {
-    if (string != NULL) {
-        MZ_FREE(*string);
+    if (string) {
+        free(*string);
         *string = NULL;
     }
 }
@@ -116,7 +104,7 @@ int32_t mz_os_rand(uint8_t *buf, int32_t size) {
     for (len = 0; len < (int)size; len += 1) {
         if (len % 8 == 0)
             QueryPerformanceCounter((LARGE_INTEGER *)pentium_tsc);
-        buf[len] = ((unsigned char*)pentium_tsc)[len % 8];
+        buf[len] = ((unsigned char *)pentium_tsc)[len % 8];
     }
 
     return len;
@@ -128,20 +116,20 @@ int32_t mz_os_rename(const char *source_path, const char *target_path) {
     int32_t result = 0;
     int32_t err = MZ_OK;
 
-    if (source_path == NULL || target_path == NULL)
+    if (!source_path || !target_path)
         return MZ_PARAM_ERROR;
 
     source_path_wide = mz_os_unicode_string_create(source_path, MZ_ENCODING_UTF8);
-    if (source_path_wide == NULL) {
+    if (!source_path_wide) {
         err = MZ_PARAM_ERROR;
     } else {
         target_path_wide = mz_os_unicode_string_create(target_path, MZ_ENCODING_UTF8);
-        if (target_path_wide == NULL)
+        if (!target_path_wide)
             err = MZ_PARAM_ERROR;
     }
 
     if (err == MZ_OK) {
-#ifdef MZ_WINRT_API
+#if _WIN32_WINNT >= _WIN32_WINNT_WINXP
         result = MoveFileExW(source_path_wide, target_path_wide, MOVEFILE_WRITE_THROUGH);
 #else
         result = MoveFileW(source_path_wide, target_path_wide);
@@ -162,10 +150,10 @@ int32_t mz_os_unlink(const char *path) {
     wchar_t *path_wide = NULL;
     int32_t result = 0;
 
-    if (path == NULL)
+    if (!path)
         return MZ_PARAM_ERROR;
     path_wide = mz_os_unicode_string_create(path, MZ_ENCODING_UTF8);
-    if (path_wide == NULL)
+    if (!path_wide)
         return MZ_PARAM_ERROR;
 
     if (mz_os_is_dir(path) == MZ_OK)
@@ -185,10 +173,10 @@ int32_t mz_os_file_exists(const char *path) {
     wchar_t *path_wide = NULL;
     DWORD attribs = 0;
 
-    if (path == NULL)
+    if (!path)
         return MZ_PARAM_ERROR;
     path_wide = mz_os_unicode_string_create(path, MZ_ENCODING_UTF8);
-    if (path_wide == NULL)
+    if (!path_wide)
         return MZ_PARAM_ERROR;
 
     attribs = GetFileAttributesW(path_wide);
@@ -205,12 +193,12 @@ int64_t mz_os_get_file_size(const char *path) {
     LARGE_INTEGER large_size;
     wchar_t *path_wide = NULL;
 
-    if (path == NULL)
+    if (!path)
         return MZ_PARAM_ERROR;
     path_wide = mz_os_unicode_string_create(path, MZ_ENCODING_UTF8);
-    if (path_wide == NULL)
+    if (!path_wide)
         return MZ_PARAM_ERROR;
-#ifdef MZ_WINRT_API
+#if _WIN32_WINNT >= _WIN32_WINNT_WIN8
     handle = CreateFile2(path_wide, GENERIC_READ, 0, OPEN_EXISTING, NULL);
 #else
     handle = CreateFileW(path_wide, GENERIC_READ, 0, NULL, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL);
@@ -247,21 +235,21 @@ int32_t mz_os_get_file_date(const char *path, time_t *modified_date, time_t *acc
     wchar_t *path_wide = NULL;
     int32_t err = MZ_INTERNAL_ERROR;
 
-    if (path == NULL)
+    if (!path)
         return MZ_PARAM_ERROR;
     path_wide = mz_os_unicode_string_create(path, MZ_ENCODING_UTF8);
-    if (path_wide == NULL)
+    if (!path_wide)
         return MZ_PARAM_ERROR;
 
     handle = FindFirstFileW(path_wide, &ff32);
-    MZ_FREE(path_wide);
+    free(path_wide);
 
     if (handle != INVALID_HANDLE_VALUE) {
-        if (modified_date != NULL)
+        if (modified_date)
             mz_os_file_to_unix_time(ff32.ftLastWriteTime, modified_date);
-        if (accessed_date != NULL)
+        if (accessed_date)
             mz_os_file_to_unix_time(ff32.ftLastAccessTime, accessed_date);
-        if (creation_date != NULL)
+        if (creation_date)
             mz_os_file_to_unix_time(ff32.ftCreationTime, creation_date);
 
         FindClose(handle);
@@ -277,13 +265,13 @@ int32_t mz_os_set_file_date(const char *path, time_t modified_date, time_t acces
     wchar_t *path_wide = NULL;
     int32_t err = MZ_OK;
 
-    if (path == NULL)
+    if (!path)
         return MZ_PARAM_ERROR;
     path_wide = mz_os_unicode_string_create(path, MZ_ENCODING_UTF8);
-    if (path_wide == NULL)
+    if (!path_wide)
         return MZ_PARAM_ERROR;
 
-#ifdef MZ_WINRT_API
+#if _WIN32_WINNT >= _WIN32_WINNT_WIN8
     handle = CreateFile2(path_wide, GENERIC_READ | GENERIC_WRITE, 0, OPEN_EXISTING, NULL);
 #else
     handle = CreateFileW(path_wide, GENERIC_READ | GENERIC_WRITE, 0, NULL, OPEN_EXISTING, 0, NULL);
@@ -313,10 +301,10 @@ int32_t mz_os_get_file_attribs(const char *path, uint32_t *attributes) {
     wchar_t *path_wide = NULL;
     int32_t err = MZ_OK;
 
-    if (path == NULL || attributes == NULL)
+    if (!path || !attributes)
         return MZ_PARAM_ERROR;
     path_wide = mz_os_unicode_string_create(path, MZ_ENCODING_UTF8);
-    if (path_wide == NULL)
+    if (!path_wide)
         return MZ_PARAM_ERROR;
 
     *attributes = GetFileAttributesW(path_wide);
@@ -332,10 +320,10 @@ int32_t mz_os_set_file_attribs(const char *path, uint32_t attributes) {
     wchar_t *path_wide = NULL;
     int32_t err = MZ_OK;
 
-    if (path == NULL)
+    if (!path)
         return MZ_PARAM_ERROR;
     path_wide = mz_os_unicode_string_create(path, MZ_ENCODING_UTF8);
-    if (path_wide == NULL)
+    if (!path_wide)
         return MZ_PARAM_ERROR;
 
     if (SetFileAttributesW(path_wide, attributes) == 0)
@@ -349,7 +337,7 @@ int32_t mz_os_make_dir(const char *path) {
     wchar_t *path_wide = NULL;
     int32_t err = MZ_OK;
 
-    if (path == NULL)
+    if (!path)
         return MZ_PARAM_ERROR;
 
     /* Don't try to create a drive letter */
@@ -357,7 +345,7 @@ int32_t mz_os_make_dir(const char *path) {
         return mz_os_is_dir(path);
 
     path_wide = mz_os_unicode_string_create(path, MZ_ENCODING_UTF8);
-    if (path_wide == NULL)
+    if (!path_wide)
         return MZ_PARAM_ERROR;
 
     if (CreateDirectoryW(path_wide, NULL) == 0) {
@@ -377,8 +365,7 @@ DIR *mz_os_open_dir(const char *path) {
     char fixed_path[320];
     void *handle = NULL;
 
-
-    if (path == NULL)
+    if (!path)
         return NULL;
 
     strncpy(fixed_path, path, sizeof(fixed_path) - 1);
@@ -388,7 +375,7 @@ DIR *mz_os_open_dir(const char *path) {
     mz_path_combine(fixed_path, "*", sizeof(fixed_path));
 
     path_wide = mz_os_unicode_string_create(fixed_path, MZ_ENCODING_UTF8);
-    if (path_wide == NULL)
+    if (!path_wide)
         return NULL;
 
     handle = FindFirstFileW(path_wide, &find_data);
@@ -397,9 +384,11 @@ DIR *mz_os_open_dir(const char *path) {
     if (handle == INVALID_HANDLE_VALUE)
         return NULL;
 
-    dir_int = (DIR_int *)MZ_ALLOC(sizeof(DIR_int));
-    if (dir_int == NULL)
+    dir_int = (DIR_int *)malloc(sizeof(DIR_int));
+    if (!dir_int) {
+        FindClose(handle);
         return NULL;
+    }
     dir_int->find_handle = handle;
     dir_int->end = 0;
 
@@ -411,7 +400,7 @@ DIR *mz_os_open_dir(const char *path) {
 struct dirent* mz_os_read_dir(DIR *dir) {
     DIR_int *dir_int;
 
-    if (dir == NULL)
+    if (!dir)
         return NULL;
 
     dir_int = (DIR_int *)dir;
@@ -434,13 +423,13 @@ struct dirent* mz_os_read_dir(DIR *dir) {
 int32_t mz_os_close_dir(DIR *dir) {
     DIR_int *dir_int;
 
-    if (dir == NULL)
+    if (!dir)
         return MZ_PARAM_ERROR;
 
     dir_int = (DIR_int *)dir;
     if (dir_int->find_handle != INVALID_HANDLE_VALUE)
         FindClose(dir_int->find_handle);
-    MZ_FREE(dir_int);
+    free(dir_int);
     return MZ_OK;
 }
 
@@ -448,10 +437,10 @@ int32_t mz_os_is_dir(const char *path) {
     wchar_t *path_wide = NULL;
     uint32_t attribs = 0;
 
-    if (path == NULL)
+    if (!path)
         return MZ_PARAM_ERROR;
     path_wide = mz_os_unicode_string_create(path, MZ_ENCODING_UTF8);
-    if (path_wide == NULL)
+    if (!path_wide)
         return MZ_PARAM_ERROR;
 
     attribs = GetFileAttributesW(path_wide);
@@ -469,10 +458,10 @@ int32_t mz_os_is_symlink(const char *path) {
     wchar_t *path_wide = NULL;
     uint32_t attribs = 0;
 
-    if (path == NULL)
+    if (!path)
         return MZ_PARAM_ERROR;
     path_wide = mz_os_unicode_string_create(path, MZ_ENCODING_UTF8);
-    if (path_wide == NULL)
+    if (!path_wide)
         return MZ_PARAM_ERROR;
 
     attribs = GetFileAttributesW(path_wide);
@@ -488,6 +477,7 @@ int32_t mz_os_is_symlink(const char *path) {
 
 int32_t mz_os_make_symlink(const char *path, const char *target_path) {
     typedef BOOLEAN (WINAPI *LPCREATESYMBOLICLINKW)(LPCWSTR, LPCWSTR, DWORD);
+    MEMORY_BASIC_INFORMATION mbi;
     LPCREATESYMBOLICLINKW create_symbolic_link_w = NULL;
     HMODULE kernel32_mod = NULL;
     wchar_t *path_wide = NULL;
@@ -495,33 +485,29 @@ int32_t mz_os_make_symlink(const char *path, const char *target_path) {
     int32_t err = MZ_OK;
     int32_t flags = 0;
 
-    if (path == NULL)
+    if (!path)
         return MZ_PARAM_ERROR;
 
-#ifdef MZ_WINRT_API
-    MEMORY_BASIC_INFORMATION mbi;
+    // Use VirtualQuery instead of GetModuleHandleW for UWP
     memset(&mbi, 0, sizeof(mbi));
     VirtualQuery(VirtualQuery, &mbi, sizeof(mbi));
     kernel32_mod = (HMODULE)mbi.AllocationBase;
-#else
-    kernel32_mod = GetModuleHandleW(L"kernel32.dll");
-#endif
 
-    if (kernel32_mod == NULL)
+    if (!kernel32_mod)
         return MZ_SUPPORT_ERROR;
 
     create_symbolic_link_w = (LPCREATESYMBOLICLINKW)GetProcAddress(kernel32_mod, "CreateSymbolicLinkW");
-    if (create_symbolic_link_w == NULL) {
+    if (!create_symbolic_link_w) {
         return MZ_SUPPORT_ERROR;
     }
 
     path_wide = mz_os_unicode_string_create(path, MZ_ENCODING_UTF8);
-    if (path_wide == NULL) {
+    if (!path_wide) {
         return MZ_PARAM_ERROR;
     }
 
     target_path_wide = mz_os_unicode_string_create(target_path, MZ_ENCODING_UTF8);
-    if (target_path_wide != NULL) {
+    if (target_path_wide) {
         if (mz_path_has_slash(target_path) == MZ_OK)
             flags |= SYMBOLIC_LINK_FLAG_DIRECTORY;
 
@@ -575,13 +561,13 @@ int32_t mz_os_read_symlink(const char *path, char *target_path, int32_t max_targ
     int32_t err = MZ_OK;
     uint8_t *target_path_utf8 = NULL;
 
-    if (path == NULL)
+    if (!path)
         return MZ_PARAM_ERROR;
     path_wide = mz_os_unicode_string_create(path, MZ_ENCODING_UTF8);
-    if (path_wide == NULL)
+    if (!path_wide)
         return MZ_PARAM_ERROR;
 
-#ifdef MZ_WINRT_API
+#if _WIN32_WINNT >= _WIN32_WINNT_WIN8
     CREATEFILE2_EXTENDED_PARAMETERS extended_params;
     memset(&extended_params, 0, sizeof(extended_params));
     extended_params.dwSize = sizeof(extended_params);
@@ -609,7 +595,7 @@ int32_t mz_os_read_symlink(const char *path, char *target_path, int32_t max_targ
             if (target_path_len > reparse_data->SymbolicLinkReparseBuffer.PrintNameLength)
                 target_path_len = reparse_data->SymbolicLinkReparseBuffer.PrintNameLength;
 
-            target_path_wide = (wchar_t *)MZ_ALLOC(target_path_len + sizeof(wchar_t));
+            target_path_wide = (wchar_t *)malloc(target_path_len + sizeof(wchar_t));
             if (target_path_wide) {
                 target_path_idx = reparse_data->SymbolicLinkReparseBuffer.PrintNameOffset / sizeof(wchar_t);
                 memcpy(target_path_wide, &reparse_data->SymbolicLinkReparseBuffer.PathBuffer[target_path_idx],
@@ -629,7 +615,7 @@ int32_t mz_os_read_symlink(const char *path, char *target_path, int32_t max_targ
                     err = MZ_MEM_ERROR;
                 }
 
-                MZ_FREE(target_path_wide);
+                free(target_path_wide);
             } else {
                 err = MZ_MEM_ERROR;
             }
