@@ -1,7 +1,7 @@
 /* mz_zip_rw.c -- Zip reader/writer
    part of the minizip-ng project
 
-   Copyright (C) 2010-2021 Nathan Moinvaziri
+   Copyright (C) Nathan Moinvaziri
      https://github.com/zlib-ng/minizip-ng
 
    This program is distributed under the terms of the same license as zlib.
@@ -69,9 +69,9 @@ typedef struct mz_zip_reader_s {
 
 int32_t mz_zip_reader_is_open(void *handle) {
     mz_zip_reader *reader = (mz_zip_reader *)handle;
-    if (reader == NULL)
+    if (!reader)
         return MZ_PARAM_ERROR;
-    if (reader->zip_handle == NULL)
+    if (!reader->zip_handle)
         return MZ_PARAM_ERROR;
     return MZ_OK;
 }
@@ -101,7 +101,6 @@ int32_t mz_zip_reader_open_file(void *handle, const char *path) {
     mz_zip_reader *reader = (mz_zip_reader *)handle;
     int32_t err = MZ_OK;
 
-
     mz_zip_reader_close(handle);
 
     mz_stream_os_create(&reader->file_stream);
@@ -123,7 +122,6 @@ int32_t mz_zip_reader_open_file_in_memory(void *handle, const char *path) {
     int64_t file_size = 0;
     int32_t err = 0;
 
-
     mz_zip_reader_close(handle);
 
     mz_stream_os_create(&file_stream);
@@ -194,23 +192,23 @@ int32_t mz_zip_reader_close(void *handle) {
     mz_zip_reader *reader = (mz_zip_reader *)handle;
     int32_t err = MZ_OK;
 
-    if (reader->zip_handle != NULL) {
+    if (reader->zip_handle) {
         err = mz_zip_close(reader->zip_handle);
         mz_zip_delete(&reader->zip_handle);
     }
 
-    if (reader->split_stream != NULL) {
+    if (reader->split_stream) {
         mz_stream_split_close(reader->split_stream);
         mz_stream_split_delete(&reader->split_stream);
     }
 
-    if (reader->buffered_stream != NULL)
+    if (reader->buffered_stream)
         mz_stream_buffered_delete(&reader->buffered_stream);
 
-    if (reader->file_stream != NULL)
+    if (reader->file_stream)
         mz_stream_os_delete(&reader->file_stream);
 
-    if (reader->mem_stream != NULL) {
+    if (reader->mem_stream) {
         mz_stream_close(reader->mem_stream);
         mz_stream_delete(&reader->mem_stream);
     }
@@ -229,7 +227,6 @@ int32_t mz_zip_reader_unzip_cd(void *handle) {
     uint64_t number_entry = 0;
     int32_t err = MZ_OK;
 
-
     err = mz_zip_reader_goto_first_entry(handle);
     if (err != MZ_OK)
         return err;
@@ -300,7 +297,7 @@ int32_t mz_zip_reader_goto_first_entry(void *handle) {
     if (mz_zip_entry_is_open(reader->zip_handle) == MZ_OK)
         mz_zip_reader_entry_close(handle);
 
-    if (reader->pattern == NULL)
+    if (!reader->pattern)
         err = mz_zip_goto_first_entry(reader->zip_handle);
     else
         err = mz_zip_locate_first_entry(reader->zip_handle, reader, mz_zip_reader_locate_entry_cb);
@@ -322,7 +319,7 @@ int32_t mz_zip_reader_goto_next_entry(void *handle) {
     if (mz_zip_entry_is_open(reader->zip_handle) == MZ_OK)
         mz_zip_reader_entry_close(handle);
 
-    if (reader->pattern == NULL)
+    if (!reader->pattern)
         err = mz_zip_goto_next_entry(reader->zip_handle);
     else
         err = mz_zip_locate_next_entry(reader->zip_handle, reader, mz_zip_reader_locate_entry_cb);
@@ -358,12 +355,11 @@ int32_t mz_zip_reader_entry_open(void *handle) {
     const char *password = NULL;
     char password_buf[120];
 
-
     reader->entry_verified = 0;
 
     if (mz_zip_reader_is_open(reader) != MZ_OK)
         return MZ_PARAM_ERROR;
-    if (reader->file_info == NULL)
+    if (!reader->file_info)
         return MZ_PARAM_ERROR;
 
     /* If the entry isn't open for reading, open it */
@@ -373,8 +369,7 @@ int32_t mz_zip_reader_entry_open(void *handle) {
     password = reader->password;
 
     /* Check if we need a password and ask for it if we need to */
-    if ((reader->file_info->flag & MZ_ZIP_FLAG_ENCRYPTED) && (password == NULL) &&
-        (reader->password_cb != NULL)) {
+    if (!password && reader->password_cb && (reader->file_info->flag & MZ_ZIP_FLAG_ENCRYPTED)) {
         reader->password_cb(handle, reader->password_userdata, reader->file_info,
             password_buf, sizeof(password_buf));
 
@@ -423,7 +418,7 @@ int32_t mz_zip_reader_entry_close(void *handle) {
     uint8_t computed_hash[MZ_HASH_MAX_SIZE];
     uint8_t expected_hash[MZ_HASH_MAX_SIZE];
 
-    if (reader->hash != NULL) {
+    if (reader->hash) {
         mz_crypt_sha_end(reader->hash, computed_hash, sizeof(computed_hash));
         mz_crypt_sha_delete(&reader->hash);
 
@@ -449,7 +444,7 @@ int32_t mz_zip_reader_entry_read(void *handle, void *buf, int32_t len) {
     int32_t read = 0;
     read = mz_zip_entry_read(reader->zip_handle, buf, len);
 #ifndef MZ_ZIP_NO_CRYPTO
-    if ((read > 0) && (reader->hash != NULL))
+    if (read > 0 && reader->hash)
         mz_crypt_sha_update(reader->hash, buf, read);
 #endif
     return read;
@@ -458,7 +453,7 @@ int32_t mz_zip_reader_entry_read(void *handle, void *buf, int32_t len) {
 int32_t mz_zip_reader_entry_has_sign(void *handle) {
     mz_zip_reader *reader = (mz_zip_reader *)handle;
 
-    if (reader == NULL || mz_zip_entry_is_open(reader->zip_handle) != MZ_OK)
+    if (!reader || mz_zip_entry_is_open(reader->zip_handle) != MZ_OK)
         return MZ_PARAM_ERROR;
 
     return mz_zip_extrafield_contains(reader->file_info->extrafield,
@@ -474,7 +469,7 @@ int32_t mz_zip_reader_entry_sign_verify(void *handle) {
     uint16_t signature_size = 0;
     uint8_t hash[MZ_HASH_MAX_SIZE];
 
-    if (reader == NULL || mz_zip_entry_is_open(reader->zip_handle) != MZ_OK)
+    if (!reader || mz_zip_entry_is_open(reader->zip_handle) != MZ_OK)
         return MZ_PARAM_ERROR;
 
     mz_stream_mem_create(&file_extra_stream);
@@ -483,7 +478,7 @@ int32_t mz_zip_reader_entry_sign_verify(void *handle) {
 
     err = mz_zip_extrafield_find(file_extra_stream, MZ_ZIP_EXTENSION_SIGN, INT32_MAX, &signature_size);
     if ((err == MZ_OK) && (signature_size > 0)) {
-        signature = (uint8_t *)MZ_ALLOC(signature_size);
+        signature = (uint8_t *)malloc(signature_size);
         if (mz_stream_read(file_extra_stream, signature, signature_size) != signature_size)
             err = MZ_READ_ERROR;
     }
@@ -500,8 +495,8 @@ int32_t mz_zip_reader_entry_sign_verify(void *handle) {
         err = mz_crypt_sign_verify(hash, reader->hash_digest_size, signature, signature_size);
     }
 
-    if (signature != NULL)
-        MZ_FREE(signature);
+    if (signature)
+        free(signature);
 
     return err;
 }
@@ -550,7 +545,7 @@ int32_t mz_zip_reader_entry_get_first_hash(void *handle, uint16_t *algorithm, ui
     uint16_t cur_algorithm = 0;
     uint16_t cur_digest_size = 0;
 
-    if (reader == NULL || algorithm == NULL)
+    if (!reader || !algorithm)
         return MZ_PARAM_ERROR;
 
     mz_stream_mem_create(&file_extra_stream);
@@ -563,9 +558,9 @@ int32_t mz_zip_reader_entry_get_first_hash(void *handle, uint16_t *algorithm, ui
     if (err == MZ_OK)
         err = mz_stream_read_uint16(file_extra_stream, &cur_digest_size);
 
-    if (algorithm != NULL)
+    if (algorithm)
         *algorithm = cur_algorithm;
-    if (digest_size != NULL)
+    if (digest_size)
         *digest_size = cur_digest_size;
 
     mz_stream_mem_delete(&file_extra_stream);
@@ -576,10 +571,10 @@ int32_t mz_zip_reader_entry_get_first_hash(void *handle, uint16_t *algorithm, ui
 int32_t mz_zip_reader_entry_get_info(void *handle, mz_zip_file **file_info) {
     mz_zip_reader *reader = (mz_zip_reader *)handle;
     int32_t err = MZ_OK;
-    if (file_info == NULL || mz_zip_reader_is_open(handle) != MZ_OK)
+    if (!file_info || mz_zip_reader_is_open(handle) != MZ_OK)
         return MZ_PARAM_ERROR;
     *file_info = reader->file_info;
-    if (*file_info == NULL)
+    if (!*file_info)
         return MZ_EXIST_ERROR;
     return err;
 }
@@ -597,12 +592,9 @@ int32_t mz_zip_reader_entry_save_process(void *handle, void *stream, mz_stream_w
     int32_t read = 0;
     int32_t written = 0;
 
-
     if (mz_zip_reader_is_open(reader) != MZ_OK)
         return MZ_PARAM_ERROR;
-    if (reader->file_info == NULL)
-        return MZ_PARAM_ERROR;
-    if (write_cb == NULL)
+    if (!reader->file_info || !write_cb)
         return MZ_PARAM_ERROR;
 
     /* If the entry isn't open for reading, open it */
@@ -645,11 +637,11 @@ int32_t mz_zip_reader_entry_save(void *handle, void *stream, mz_stream_write_cb
 
     if (mz_zip_reader_is_open(reader) != MZ_OK)
         return MZ_PARAM_ERROR;
-    if (reader->file_info == NULL)
+    if (!reader->file_info)
         return MZ_PARAM_ERROR;
 
     /* Update the progress at the beginning */
-    if (reader->progress_cb != NULL)
+    if (reader->progress_cb)
         reader->progress_cb(handle, reader->progress_userdata, reader->file_info, current_pos);
 
     /* Write data to stream until done */
@@ -665,7 +657,7 @@ int32_t mz_zip_reader_entry_save(void *handle, void *stream, mz_stream_write_cb
         /* Update progress if enough time have passed */
         current_time = mz_os_ms_time();
         if ((current_time - update_time) > reader->progress_cb_interval_ms) {
-            if (reader->progress_cb != NULL)
+            if (reader->progress_cb)
                 reader->progress_cb(handle, reader->progress_userdata, reader->file_info, current_pos);
 
             update_pos = current_pos;
@@ -674,7 +666,7 @@ int32_t mz_zip_reader_entry_save(void *handle, void *stream, mz_stream_write_cb
     }
 
     /* Update the progress at the end */
-    if (reader->progress_cb != NULL && update_pos != current_pos)
+    if (reader->progress_cb && update_pos != current_pos)
         reader->progress_cb(handle, reader->progress_userdata, reader->file_info, current_pos);
 
     return err;
@@ -692,7 +684,7 @@ int32_t mz_zip_reader_entry_save_file(void *handle, const char *path) {
 
     if (mz_zip_reader_is_open(reader) != MZ_OK)
         return MZ_PARAM_ERROR;
-    if (reader->file_info == NULL || path == NULL)
+    if (!reader->file_info || !path)
         return MZ_PARAM_ERROR;
 
     /* Convert to forward slashes for unix which doesn't like backslashes */
@@ -700,7 +692,7 @@ int32_t mz_zip_reader_entry_save_file(void *handle, const char *path) {
     pathwfs[sizeof(pathwfs) - 1] = 0;
     mz_path_convert_slashes(pathwfs, MZ_PATH_SLASH_UNIX);
 
-    if (reader->entry_cb != NULL)
+    if (reader->entry_cb)
         reader->entry_cb(handle, reader->entry_userdata, reader->file_info, pathwfs);
 
     strncpy(directory, pathwfs, sizeof(directory) - 1);
@@ -715,7 +707,7 @@ int32_t mz_zip_reader_entry_save_file(void *handle, const char *path) {
     }
 
     /* Check if file exists and ask if we want to overwrite */
-    if ((mz_os_file_exists(pathwfs) == MZ_OK) && (reader->overwrite_cb != NULL)) {
+    if (reader->overwrite_cb && mz_os_file_exists(pathwfs) == MZ_OK) {
         err_cb = reader->overwrite_cb(handle, reader->overwrite_userdata, reader->file_info, pathwfs);
         if (err_cb != MZ_OK)
             return err;
@@ -724,7 +716,8 @@ int32_t mz_zip_reader_entry_save_file(void *handle, const char *path) {
     }
 
     /* If symbolic link then properly construct destination path and link path */
-    if (mz_zip_entry_is_symlink(reader->zip_handle) == MZ_OK) {
+    if ((mz_zip_entry_is_symlink(reader->zip_handle) == MZ_OK) &&
+        (mz_path_has_slash(pathwfs) == MZ_OK)) {
         mz_path_remove_slash(pathwfs);
         mz_path_remove_filename(directory);
     }
@@ -738,7 +731,30 @@ int32_t mz_zip_reader_entry_save_file(void *handle, const char *path) {
 
     /* If it is a symbolic link then create symbolic link instead of writing file */
     if (mz_zip_entry_is_symlink(reader->zip_handle) == MZ_OK) {
-        mz_os_make_symlink(pathwfs, reader->file_info->linkname);
+        if (reader->file_info->linkname && *reader->file_info->linkname != 0) {
+            /* Create symbolic link from UNIX1 extrafield */
+            err = mz_os_make_symlink(pathwfs, reader->file_info->linkname);
+        } else if (reader->file_info->uncompressed_size < UINT16_MAX) {
+            /* Create symbolic link from zip entry contents */
+            mz_stream_mem_create(&stream);
+            err = mz_stream_mem_open(stream, NULL, MZ_OPEN_MODE_CREATE);
+
+            if (err == MZ_OK)
+                err = mz_zip_reader_entry_save(handle, stream, mz_stream_write);
+
+            if (err == MZ_OK)
+                err = mz_stream_write_uint8(stream, 0);
+
+            if (err == MZ_OK) {
+                const char *linkname = NULL;
+                if (mz_stream_mem_get_buffer(stream, (const void **)&linkname) == MZ_OK)
+                    err = mz_os_make_symlink(pathwfs, linkname);
+            }
+
+            mz_stream_mem_close(stream);
+            mz_stream_mem_delete(&stream);
+        }
+
         /* Don't check return value because we aren't validating symbolic link target */
         return err;
     }
@@ -778,9 +794,7 @@ int32_t mz_zip_reader_entry_save_buffer(void *handle, void *buf, int32_t len) {
 
     if (mz_zip_reader_is_open(reader) != MZ_OK)
         return MZ_PARAM_ERROR;
-    if (reader->file_info == NULL)
-        return MZ_PARAM_ERROR;
-    if (reader->file_info->uncompressed_size > INT32_MAX)
+    if (!reader->file_info || reader->file_info->uncompressed_size > INT32_MAX)
         return MZ_PARAM_ERROR;
     if (len != (int32_t)reader->file_info->uncompressed_size)
         return MZ_BUF_ERROR;
@@ -802,9 +816,7 @@ int32_t mz_zip_reader_entry_save_buffer_length(void *handle) {
 
     if (mz_zip_reader_is_open(reader) != MZ_OK)
         return MZ_PARAM_ERROR;
-    if (reader->file_info == NULL)
-        return MZ_PARAM_ERROR;
-    if (reader->file_info->uncompressed_size > INT32_MAX)
+    if (!reader->file_info || reader->file_info->uncompressed_size > INT32_MAX)
         return MZ_PARAM_ERROR;
 
     /* Get the maximum size required for the save buffer */
@@ -846,7 +858,7 @@ int32_t mz_zip_reader_save_all(void *handle, const char *destination_dir) {
         if (err != MZ_OK)
             break;
 
-        if (destination_dir != NULL)
+        if (destination_dir)
             mz_path_combine(path, destination_dir, sizeof(path));
 
         mz_path_combine(path, resolved_name, sizeof(path));
@@ -884,7 +896,7 @@ void mz_zip_reader_set_raw(void *handle, uint8_t raw) {
 
 int32_t mz_zip_reader_get_raw(void *handle, uint8_t *raw) {
     mz_zip_reader *reader = (mz_zip_reader *)handle;
-    if (raw == NULL)
+    if (!raw)
         return MZ_PARAM_ERROR;
     *raw = reader->raw;
     return MZ_OK;
@@ -892,7 +904,7 @@ int32_t mz_zip_reader_get_raw(void *handle, uint8_t *raw) {
 
 int32_t mz_zip_reader_get_zip_cd(void *handle, uint8_t *zip_cd) {
     mz_zip_reader *reader = (mz_zip_reader *)handle;
-    if (zip_cd == NULL)
+    if (!zip_cd)
         return MZ_PARAM_ERROR;
     *zip_cd = reader->cd_zipped;
     return MZ_OK;
@@ -902,14 +914,14 @@ int32_t mz_zip_reader_get_comment(void *handle, const char **comment) {
     mz_zip_reader *reader = (mz_zip_reader *)handle;
     if (mz_zip_reader_is_open(reader) != MZ_OK)
         return MZ_PARAM_ERROR;
-    if (comment == NULL)
+    if (!comment)
         return MZ_PARAM_ERROR;
     return mz_zip_get_comment(reader->zip_handle, comment);
 }
 
 int32_t mz_zip_reader_set_recover(void *handle, uint8_t recover) {
     mz_zip_reader *reader = (mz_zip_reader *)handle;
-    if (reader == NULL)
+    if (!reader)
         return MZ_PARAM_ERROR;
     reader->recover = recover;
     return MZ_OK;
@@ -956,10 +968,10 @@ void mz_zip_reader_set_entry_cb(void *handle, void *userdata, mz_zip_reader_entr
 
 int32_t mz_zip_reader_get_zip_handle(void *handle, void **zip_handle) {
     mz_zip_reader *reader = (mz_zip_reader *)handle;
-    if (zip_handle == NULL)
+    if (!zip_handle)
         return MZ_PARAM_ERROR;
     *zip_handle = reader->zip_handle;
-    if (*zip_handle == NULL)
+    if (!*zip_handle)
         return MZ_EXIST_ERROR;
     return MZ_OK;
 }
@@ -969,13 +981,12 @@ int32_t mz_zip_reader_get_zip_handle(void *handle, void **zip_handle) {
 void *mz_zip_reader_create(void **handle) {
     mz_zip_reader *reader = NULL;
 
-    reader = (mz_zip_reader *)MZ_ALLOC(sizeof(mz_zip_reader));
-    if (reader != NULL) {
-        memset(reader, 0, sizeof(mz_zip_reader));
+    reader = (mz_zip_reader *)calloc(1, sizeof(mz_zip_reader));
+    if (reader) {
         reader->recover = 1;
         reader->progress_cb_interval_ms = MZ_DEFAULT_PROGRESS_INTERVAL;
     }
-    if (handle != NULL)
+    if (handle)
         *handle = reader;
 
     return reader;
@@ -983,12 +994,12 @@ void *mz_zip_reader_create(void **handle) {
 
 void mz_zip_reader_delete(void **handle) {
     mz_zip_reader *reader = NULL;
-    if (handle == NULL)
+    if (!handle)
         return;
     reader = (mz_zip_reader *)*handle;
-    if (reader != NULL) {
+    if (reader) {
         mz_zip_reader_close(reader);
-        MZ_FREE(reader);
+        free(reader);
     }
     *handle = NULL;
 }
@@ -1044,7 +1055,6 @@ int32_t mz_zip_writer_zip_cd(void *handle) {
     void *file_extra_stream = NULL;
     void *cd_mem_stream = NULL;
 
-
     memset(&cd_file, 0, sizeof(cd_file));
 
     mz_zip_get_number_entry(writer->zip_handle, &number_entry);
@@ -1060,7 +1070,7 @@ int32_t mz_zip_writer_zip_cd(void *handle) {
     cd_file.uncompressed_size = (int32_t)cd_mem_length;
     cd_file.flag = MZ_ZIP_FLAG_UTF8;
 
-    if (writer->password != NULL)
+    if (writer->password)
         cd_file.flag |= MZ_ZIP_FLAG_ENCRYPTED;
 
     mz_stream_mem_create(&file_extra_stream);
@@ -1094,9 +1104,7 @@ int32_t mz_zip_writer_zip_cd(void *handle) {
 
 int32_t mz_zip_writer_is_open(void *handle) {
     mz_zip_writer *writer = (mz_zip_writer *)handle;
-    if (writer == NULL)
-        return MZ_PARAM_ERROR;
-    if (writer->zip_handle == NULL)
+    if (!writer || !writer->zip_handle)
         return MZ_PARAM_ERROR;
     return MZ_OK;
 }
@@ -1142,7 +1150,7 @@ int32_t mz_zip_writer_open_file(void *handle, const char *path, int64_t disk_siz
         mode |= MZ_OPEN_MODE_CREATE;
 
         /* Create destination directory if it doesn't already exist */
-        if (strchr(path, '/') != NULL || strrchr(path, '\\') != NULL) {
+        if (strchr(path, '/') || strrchr(path, '\\')) {
             strncpy(directory, path, sizeof(directory) - 1);
             directory[sizeof(directory) - 1] = 0;
             mz_path_remove_filename(directory);
@@ -1152,7 +1160,7 @@ int32_t mz_zip_writer_open_file(void *handle, const char *path, int64_t disk_siz
     } else if (append) {
         mode |= MZ_OPEN_MODE_APPEND;
     } else {
-        if (writer->overwrite_cb != NULL)
+        if (writer->overwrite_cb)
             err_cb = writer->overwrite_cb(handle, writer->overwrite_userdata, path);
 
         if (err_cb == MZ_INTERNAL_ERROR)
@@ -1186,7 +1194,6 @@ int32_t mz_zip_writer_open_file_in_memory(void *handle, const char *path) {
     int64_t file_size = 0;
     int32_t err = 0;
 
-
     mz_zip_writer_close(handle);
 
     mz_stream_os_create(&file_stream);
@@ -1233,8 +1240,7 @@ int32_t mz_zip_writer_close(void *handle) {
     mz_zip_writer *writer = (mz_zip_writer *)handle;
     int32_t err = MZ_OK;
 
-
-    if (writer->zip_handle != NULL) {
+    if (writer->zip_handle) {
         mz_zip_set_version_madeby(writer->zip_handle, MZ_VERSION_MADEBY);
         if (writer->comment)
             mz_zip_set_comment(writer->zip_handle, writer->comment);
@@ -1245,18 +1251,18 @@ int32_t mz_zip_writer_close(void *handle) {
         mz_zip_delete(&writer->zip_handle);
     }
 
-    if (writer->split_stream != NULL) {
+    if (writer->split_stream) {
         mz_stream_split_close(writer->split_stream);
         mz_stream_split_delete(&writer->split_stream);
     }
 
-    if (writer->buffered_stream != NULL)
+    if (writer->buffered_stream)
         mz_stream_buffered_delete(&writer->buffered_stream);
 
-    if (writer->file_stream != NULL)
+    if (writer->file_stream)
         mz_stream_os_delete(&writer->file_stream);
 
-    if (writer->mem_stream != NULL) {
+    if (writer->mem_stream) {
         mz_stream_mem_close(writer->mem_stream);
         mz_stream_mem_delete(&writer->mem_stream);
     }
@@ -1275,14 +1281,13 @@ int32_t mz_zip_writer_entry_open(void *handle, mz_zip_file *file_info) {
     /* Copy file info to access data upon close */
     memcpy(&writer->file_info, file_info, sizeof(mz_zip_file));
 
-    if (writer->entry_cb != NULL)
+    if (writer->entry_cb)
         writer->entry_cb(handle, writer->entry_userdata, &writer->file_info);
 
     password = writer->password;
 
     /* Check if we need a password and ask for it if we need to */
-    if ((writer->file_info.flag & MZ_ZIP_FLAG_ENCRYPTED) && (password == NULL) &&
-        (writer->password_cb != NULL)) {
+    if (!password && writer->password_cb && (writer->file_info.flag & MZ_ZIP_FLAG_ENCRYPTED)) {
         writer->password_cb(handle, writer->password_userdata, &writer->file_info,
             password_buf, sizeof(password_buf));
         password = password_buf;
@@ -1312,8 +1317,7 @@ int32_t mz_zip_writer_entry_sign(void *handle, uint8_t *message, int32_t message
     int32_t signature_size = 0;
     uint8_t *signature = NULL;
 
-
-    if (writer == NULL || cert_data == NULL || cert_data_size <= 0)
+    if (!writer || !cert_data || cert_data_size <= 0)
         return MZ_PARAM_ERROR;
     if (mz_zip_entry_is_open(writer->zip_handle) != MZ_OK)
         return MZ_PARAM_ERROR;
@@ -1322,7 +1326,7 @@ int32_t mz_zip_writer_entry_sign(void *handle, uint8_t *message, int32_t message
     err = mz_crypt_sign(message, message_size, cert_data, cert_data_size, cert_pwd,
         &signature, &signature_size);
 
-    if ((err == MZ_OK) && (signature != NULL)) {
+    if (err == MZ_OK && signature) {
         /* Write signature zip extra field */
         err = mz_zip_extrafield_write(writer->file_extra_stream, MZ_ZIP_EXTENSION_SIGN,
             (uint16_t)signature_size);
@@ -1332,7 +1336,7 @@ int32_t mz_zip_writer_entry_sign(void *handle, uint8_t *message, int32_t message
                 err = MZ_WRITE_ERROR;
         }
 
-        MZ_FREE(signature);
+        free(signature);
     }
 
     return err;
@@ -1348,8 +1352,7 @@ int32_t mz_zip_writer_entry_close(void *handle) {
     int16_t field_length_hash = 0;
     uint8_t sha256[MZ_HASH_SHA256_SIZE];
 
-
-    if (writer->sha256 != NULL) {
+    if (writer->sha256) {
         mz_crypt_sha_end(writer->sha256, sha256, sizeof(sha256));
         mz_crypt_sha_delete(&writer->sha256);
 
@@ -1370,7 +1373,7 @@ int32_t mz_zip_writer_entry_close(void *handle) {
         }
 
 #ifdef MZ_ZIP_SIGNING
-        if ((err == MZ_OK) && (writer->cert_data != NULL) && (writer->cert_data_size > 0)) {
+        if ((err == MZ_OK) && (writer->cert_data) && (writer->cert_data_size > 0)) {
             /* Sign entry if not zipping cd or if it is cd being zipped */
             if (!writer->zip_cd || strcmp(writer->file_info.filename, MZ_ZIP_CD_FILENAME) == 0) {
                 err = mz_zip_writer_entry_sign(handle, sha256, sizeof(sha256),
@@ -1379,7 +1382,7 @@ int32_t mz_zip_writer_entry_close(void *handle) {
         }
 #endif
 
-        if ((writer->file_info.extrafield != NULL) && (writer->file_info.extrafield_size > 0))
+        if ((writer->file_info.extrafield) && (writer->file_info.extrafield_size > 0))
             mz_stream_mem_write(writer->file_extra_stream, writer->file_info.extrafield,
                 writer->file_info.extrafield_size);
 
@@ -1399,7 +1402,7 @@ int32_t mz_zip_writer_entry_close(void *handle) {
             err = mz_zip_entry_close(writer->zip_handle);
     }
 
-    if (writer->file_extra_stream != NULL)
+    if (writer->file_extra_stream)
         mz_stream_mem_delete(&writer->file_extra_stream);
 
     return err;
@@ -1410,7 +1413,7 @@ int32_t mz_zip_writer_entry_write(void *handle, const void *buf, int32_t len) {
     int32_t written = 0;
     written = mz_zip_entry_write(writer->zip_handle, buf, len);
 #ifndef MZ_ZIP_NO_CRYPTO
-    if ((written > 0) && (writer->sha256 != NULL))
+    if (written > 0 && writer->sha256)
         mz_crypt_sha_update(writer->sha256, buf, written);
 #endif
     return written;
@@ -1428,7 +1431,7 @@ int32_t mz_zip_writer_add_process(void *handle, void *stream, mz_stream_read_cb
     /* If the entry isn't open for writing, open it */
     if (mz_zip_entry_is_open(writer->zip_handle) != MZ_OK)
         return MZ_PARAM_ERROR;
-    if (read_cb == NULL)
+    if (!read_cb)
         return MZ_PARAM_ERROR;
 
     read = read_cb(stream, writer->buffer, sizeof(writer->buffer));
@@ -1456,7 +1459,7 @@ int32_t mz_zip_writer_add(void *handle, void *stream, mz_stream_read_cb read_cb)
     int32_t written = 0;
 
     /* Update the progress at the beginning */
-    if (writer->progress_cb != NULL)
+    if (writer->progress_cb)
         writer->progress_cb(handle, writer->progress_userdata, &writer->file_info, current_pos);
 
     /* Write data to stream until done */
@@ -1472,7 +1475,7 @@ int32_t mz_zip_writer_add(void *handle, void *stream, mz_stream_read_cb read_cb)
         /* Update progress if enough time have passed */
         current_time = mz_os_ms_time();
         if ((current_time - update_time) > writer->progress_cb_interval_ms) {
-            if (writer->progress_cb != NULL)
+            if (writer->progress_cb)
                 writer->progress_cb(handle, writer->progress_userdata, &writer->file_info, current_pos);
 
             update_pos = current_pos;
@@ -1481,7 +1484,7 @@ int32_t mz_zip_writer_add(void *handle, void *stream, mz_stream_read_cb read_cb)
     }
 
     /* Update the progress at the end */
-    if (writer->progress_cb != NULL && update_pos != current_pos)
+    if (writer->progress_cb && update_pos != current_pos)
         writer->progress_cb(handle, writer->progress_userdata, &writer->file_info, current_pos);
 
     return err;
@@ -1491,10 +1494,9 @@ int32_t mz_zip_writer_add_info(void *handle, void *stream, mz_stream_read_cb rea
     mz_zip_writer *writer = (mz_zip_writer *)handle;
     int32_t err = MZ_OK;
 
-
     if (mz_zip_writer_is_open(handle) != MZ_OK)
         return MZ_PARAM_ERROR;
-    if (file_info == NULL)
+    if (!file_info)
         return MZ_PARAM_ERROR;
 
     /* Add to zip */
@@ -1502,7 +1504,7 @@ int32_t mz_zip_writer_add_info(void *handle, void *stream, mz_stream_read_cb rea
     if (err != MZ_OK)
         return err;
 
-    if (stream != NULL) {
+    if (stream) {
         if (mz_zip_attrib_is_dir(writer->file_info.external_fa, writer->file_info.version_madeby) != MZ_OK) {
             err = mz_zip_writer_add(handle, stream, read_cb);
             if (err != MZ_OK)
@@ -1521,7 +1523,7 @@ int32_t mz_zip_writer_add_buffer(void *handle, void *buf, int32_t len, mz_zip_fi
 
     if (mz_zip_writer_is_open(handle) != MZ_OK)
         return MZ_PARAM_ERROR;
-    if (buf == NULL)
+    if (!buf)
         return MZ_PARAM_ERROR;
 
     /* Create a memory stream backed by our buffer and add from it */
@@ -1547,13 +1549,12 @@ int32_t mz_zip_writer_add_file(void *handle, const char *path, const char *filen
     char link_path[1024];
     const char *filename = filename_in_zip;
 
-
     if (mz_zip_writer_is_open(handle) != MZ_OK)
         return MZ_PARAM_ERROR;
-    if (path == NULL)
+    if (!path)
         return MZ_PARAM_ERROR;
 
-    if (filename == NULL) {
+    if (!filename) {
         err = mz_path_get_filename(path, &filename);
         if (err != MZ_OK)
             return err;
@@ -1607,7 +1608,7 @@ int32_t mz_zip_writer_add_file(void *handle, const char *path, const char *filen
     if (err == MZ_OK)
         err = mz_zip_writer_add_info(handle, stream, mz_stream_read, &file_info);
 
-    if (stream != NULL) {
+    if (stream) {
         mz_stream_close(stream);
         mz_stream_delete(&stream);
     }
@@ -1628,8 +1629,7 @@ int32_t mz_zip_writer_add_path(void *handle, const char *path, const char *root_
     char full_path[1024];
     char path_dir[1024];
 
-
-    if (strrchr(path, '*') != NULL) {
+    if (strrchr(path, '*')) {
         strncpy(path_dir, path, sizeof(path_dir) - 1);
         path_dir[sizeof(path_dir) - 1] = 0;
         mz_path_remove_filename(path_dir);
@@ -1640,7 +1640,7 @@ int32_t mz_zip_writer_add_path(void *handle, const char *path, const char *root_
             is_dir = 1;
 
         /* Construct the filename that our file will be stored in the zip as */
-        if (root_path == NULL)
+        if (!root_path)
             root_path = path;
 
         /* Should the file be stored with any path info at all? */
@@ -1672,10 +1672,10 @@ int32_t mz_zip_writer_add_path(void *handle, const char *path, const char *root_
 
     dir = mz_os_open_dir(path);
 
-    if (dir == NULL)
+    if (!dir)
         return MZ_EXIST_ERROR;
 
-    while ((entry = mz_os_read_dir(dir)) != NULL) {
+    while ((entry = mz_os_read_dir(dir))) {
         if (strcmp(entry->d_name, ".") == 0 || strcmp(entry->d_name, "..") == 0)
             continue;
 
@@ -1686,7 +1686,7 @@ int32_t mz_zip_writer_add_path(void *handle, const char *path, const char *root_
         if (!recursive && mz_os_is_dir(full_path) == MZ_OK)
             continue;
 
-        if ((wildcard_ptr != NULL) && (mz_path_compare_wc(entry->d_name, wildcard_ptr, 1) != MZ_OK))
+        if ((wildcard_ptr) && (mz_path_compare_wc(entry->d_name, wildcard_ptr, 1) != MZ_OK))
             continue;
 
         err = mz_zip_writer_add_path(handle, full_path, root_path, include_path, recursive);
@@ -1709,7 +1709,6 @@ int32_t mz_zip_writer_copy_from_reader(void *handle, void *reader) {
     void *reader_zip_handle = NULL;
     void *writer_zip_handle = NULL;
 
-
     if (mz_zip_reader_is_open(reader) != MZ_OK)
         return MZ_PARAM_ERROR;
     if (mz_zip_writer_is_open(writer) != MZ_OK)
@@ -1775,7 +1774,7 @@ void mz_zip_writer_set_raw(void *handle, uint8_t raw) {
 
 int32_t mz_zip_writer_get_raw(void *handle, uint8_t *raw) {
     mz_zip_writer *writer = (mz_zip_writer *)handle;
-    if (raw == NULL)
+    if (!raw)
         return MZ_PARAM_ERROR;
     *raw = writer->raw;
     return MZ_OK;
@@ -1818,7 +1817,7 @@ int32_t mz_zip_writer_set_certificate(void *handle, const char *cert_path, const
     int32_t cert_data_size = 0;
     int32_t err = MZ_OK;
 
-    if (cert_path == NULL)
+    if (!cert_path)
         return MZ_PARAM_ERROR;
 
     cert_data_size = (int32_t)mz_os_get_file_size(cert_path);
@@ -1826,12 +1825,12 @@ int32_t mz_zip_writer_set_certificate(void *handle, const char *cert_path, const
     if (cert_data_size == 0)
         return MZ_PARAM_ERROR;
 
-    if (writer->cert_data != NULL) {
-        MZ_FREE(writer->cert_data);
+    if (writer->cert_data) {
+        free(writer->cert_data);
         writer->cert_data = NULL;
     }
 
-    cert_data = (uint8_t *)MZ_ALLOC(cert_data_size);
+    cert_data = (uint8_t *)malloc(cert_data_size);
 
     /* Read pkcs12 certificate from disk */
     mz_stream_os_create(&cert_stream);
@@ -1848,7 +1847,7 @@ int32_t mz_zip_writer_set_certificate(void *handle, const char *cert_path, const
         writer->cert_data_size = cert_data_size;
         writer->cert_pwd = cert_pwd;
     } else {
-        MZ_FREE(cert_data);
+        free(cert_data);
     }
 
     return err;
@@ -1885,10 +1884,10 @@ void mz_zip_writer_set_entry_cb(void *handle, void *userdata, mz_zip_writer_entr
 
 int32_t mz_zip_writer_get_zip_handle(void *handle, void **zip_handle) {
     mz_zip_writer *writer = (mz_zip_writer *)handle;
-    if (zip_handle == NULL)
+    if (!zip_handle)
         return MZ_PARAM_ERROR;
     *zip_handle = writer->zip_handle;
-    if (*zip_handle == NULL)
+    if (!*zip_handle)
         return MZ_EXIST_ERROR;
     return MZ_OK;
 }
@@ -1898,9 +1897,8 @@ int32_t mz_zip_writer_get_zip_handle(void *handle, void **zip_handle) {
 void *mz_zip_writer_create(void **handle) {
     mz_zip_writer *writer = NULL;
 
-    writer = (mz_zip_writer *)MZ_ALLOC(sizeof(mz_zip_writer));
-    if (writer != NULL) {
-        memset(writer, 0, sizeof(mz_zip_writer));
+    writer = (mz_zip_writer *)calloc(1, sizeof(mz_zip_writer));
+    if (writer) {
 #if defined(HAVE_WZAES)
         writer->aes = 1;
 #endif
@@ -1916,7 +1914,7 @@ void *mz_zip_writer_create(void **handle) {
         writer->compress_level = MZ_COMPRESS_LEVEL_BEST;
         writer->progress_cb_interval_ms = MZ_DEFAULT_PROGRESS_INTERVAL;
     }
-    if (handle != NULL)
+    if (handle)
         *handle = writer;
 
     return writer;
@@ -1924,19 +1922,19 @@ void *mz_zip_writer_create(void **handle) {
 
 void mz_zip_writer_delete(void **handle) {
     mz_zip_writer *writer = NULL;
-    if (handle == NULL)
+    if (!handle)
         return;
     writer = (mz_zip_writer *)*handle;
-    if (writer != NULL) {
+    if (writer) {
         mz_zip_writer_close(writer);
 
-        if (writer->cert_data != NULL)
-            MZ_FREE(writer->cert_data);
+        if (writer->cert_data)
+            free(writer->cert_data);
 
         writer->cert_data = NULL;
         writer->cert_data_size = 0;
 
-        MZ_FREE(writer);
+        free(writer);
     }
     *handle = NULL;
 }
